#define QT_FEATURE_scxml 1

#define QT_FEATURE_scxml_qml 1

#define QT_FEATURE_scxml_ecmascriptdatamodel 1

#define QT_FEATURE_statemachine 1

#define QT_FEATURE_statemachine_qml 1

#define QT_FEATURE_qeventtransition 1

